summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit32b67ac0690de411b26b1d5e715b188c27442248 (patch)
tree43167816a3df6b3a877d71c9a7963ed270dcc8c9 /src
parent330c33ab6f97b279737bf9527c9add7bb1475450 (diff)
downloadtdevelop-32b67ac0690de411b26b1d5e715b188c27442248.tar.gz
tdevelop-32b67ac0690de411b26b1d5e715b188c27442248.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src')
-rw-r--r--src/generalinfowidget.cpp4
-rw-r--r--src/generalinfowidget.h2
-rw-r--r--src/languageselectwidget.cpp8
-rw-r--r--src/languageselectwidget.h2
-rw-r--r--src/mainwindowshare.cpp2
-rw-r--r--src/multibuffer.cpp6
-rw-r--r--src/multibuffer.h2
-rw-r--r--src/newui/button.cpp6
-rw-r--r--src/newui/button.h2
-rw-r--r--src/newui/buttonbar.cpp8
-rw-r--r--src/newui/buttonbar.h4
-rw-r--r--src/newui/ddockwindow.cpp8
-rw-r--r--src/newui/ddockwindow.h2
-rw-r--r--src/newui/dmainwindow.cpp4
-rw-r--r--src/newui/dmainwindow.h2
-rw-r--r--src/newui/docksplitter.cpp4
-rw-r--r--src/newui/docksplitter.h2
-rw-r--r--src/newui/dtabwidget.cpp4
-rw-r--r--src/newui/dtabwidget.h2
-rw-r--r--src/partcontroller.cpp8
-rw-r--r--src/partcontroller.h2
-rw-r--r--src/pluginselectdialog.cpp8
-rw-r--r--src/pluginselectdialog.h2
-rw-r--r--src/profileengine/editor/profileeditor.cpp24
-rw-r--r--src/profileengine/editor/profileeditor.h2
-rw-r--r--src/profileengine/lib/profile.cpp8
-rw-r--r--src/profileengine/lib/profile.h6
-rw-r--r--src/profileengine/lib/profileengine.h16
-rw-r--r--src/projectsession.cpp2
-rw-r--r--src/settingswidget.ui2
-rw-r--r--src/simplemainwindow.cpp36
-rw-r--r--src/simplemainwindow.h2
-rw-r--r--src/statusbar.cpp4
-rw-r--r--src/statusbar.h2
34 files changed, 99 insertions, 99 deletions
diff --git a/src/generalinfowidget.cpp b/src/generalinfowidget.cpp
index e1257537..d60619f0 100644
--- a/src/generalinfowidget.cpp
+++ b/src/generalinfowidget.cpp
@@ -29,8 +29,8 @@
TQString makeRelativePath(const TQString& fromPath, const TQString& toPath);
-GeneralInfoWidget::GeneralInfoWidget(TQDomDocument &projectDom, TQWidget *tqparent, const char *name)
- : GeneralInfoWidgetBase(tqparent, name), m_projectDom(projectDom) {
+GeneralInfoWidget::GeneralInfoWidget(TQDomDocument &projectDom, TQWidget *parent, const char *name)
+ : GeneralInfoWidgetBase(parent, name), m_projectDom(projectDom) {
connect(project_directory_edit, TQT_SIGNAL(textChanged(const TQString&)),
this, TQT_SLOT(slotProjectDirectoryChanged(const TQString&)));
diff --git a/src/generalinfowidget.h b/src/generalinfowidget.h
index 85f926e5..0a93f610 100644
--- a/src/generalinfowidget.h
+++ b/src/generalinfowidget.h
@@ -27,7 +27,7 @@ class GeneralInfoWidget : public GeneralInfoWidgetBase {
public:
- GeneralInfoWidget(TQDomDocument &projectDom, TQWidget *tqparent=0, const char *name=0);
+ GeneralInfoWidget(TQDomDocument &projectDom, TQWidget *parent=0, const char *name=0);
~GeneralInfoWidget();
public slots:
diff --git a/src/languageselectwidget.cpp b/src/languageselectwidget.cpp
index b21f4c3a..9fb09d0e 100644
--- a/src/languageselectwidget.cpp
+++ b/src/languageselectwidget.cpp
@@ -36,9 +36,9 @@ class LangPluginItem : public TQCheckListItem
{
public:
// name - "Name", label - "GenericName", info - "Comment"
- LangPluginItem( TQListView * tqparent, TQString const & name, TQString const & label,
+ LangPluginItem( TQListView * parent, TQString const & name, TQString const & label,
TQString const & info )
- : TQCheckListItem( tqparent, label, TQCheckListItem::CheckBox),
+ : TQCheckListItem( parent, label, TQCheckListItem::CheckBox),
_name( name ), _info( info )
{}
@@ -52,8 +52,8 @@ private:
LanguageSelectWidget::LanguageSelectWidget(TQDomDocument &projectDom,
- TQWidget *tqparent, const char *name)
- : TQWidget(tqparent, name), m_projectDom(projectDom)
+ TQWidget *parent, const char *name)
+ : TQWidget(parent, name), m_projectDom(projectDom)
{
init();
}
diff --git a/src/languageselectwidget.h b/src/languageselectwidget.h
index 9e7e31de..1fc247a3 100644
--- a/src/languageselectwidget.h
+++ b/src/languageselectwidget.h
@@ -25,7 +25,7 @@ class LanguageSelectWidget : public TQWidget
public:
/* for selection of project parts */
- LanguageSelectWidget( TQDomDocument &projectDom, TQWidget *tqparent=0, const char *name=0 );
+ LanguageSelectWidget( TQDomDocument &projectDom, TQWidget *parent=0, const char *name=0 );
~LanguageSelectWidget();
public slots:
diff --git a/src/mainwindowshare.cpp b/src/mainwindowshare.cpp
index 8e39a63d..844bc4a9 100644
--- a/src/mainwindowshare.cpp
+++ b/src/mainwindowshare.cpp
@@ -105,7 +105,7 @@ void MainWindowShare::createActions()
{
ProjectManager::getInstance()->createActions( m_pMainWnd->actionCollection() );
- KStdAction::quit(this->tqparent(), TQT_SLOT(close()), m_pMainWnd->actionCollection());
+ KStdAction::quit(this->parent(), TQT_SLOT(close()), m_pMainWnd->actionCollection());
KAction* action;
diff --git a/src/multibuffer.h b/src/multibuffer.h
index e3cabcf0..51b79466 100644
--- a/src/multibuffer.h
+++ b/src/multibuffer.h
@@ -42,7 +42,7 @@ class MultiBuffer : public TQSplitter
Q_OBJECT
TQ_OBJECT
public:
- MultiBuffer( TQWidget * tqparent = 0 );
+ MultiBuffer( TQWidget * parent = 0 );
virtual ~MultiBuffer();
KParts::Part *activeBuffer() const;
diff --git a/src/newui/button.cpp b/src/newui/button.cpp
index 1e28a827..610f545e 100644
--- a/src/newui/button.cpp
+++ b/src/newui/button.cpp
@@ -39,10 +39,10 @@
namespace Ideal {
-Button::Button(ButtonBar *tqparent, const TQString text, const TQIconSet &icon,
+Button::Button(ButtonBar *parent, const TQString text, const TQIconSet &icon,
const TQString &description)
- :TQPushButton(icon, text, tqparent), m_buttonBar(tqparent), m_description(description),
- m_place(tqparent->place()), m_realText(text), m_realIconSet(icon)
+ :TQPushButton(icon, text, parent), m_buttonBar(parent), m_description(description),
+ m_place(parent->place()), m_realText(text), m_realIconSet(icon)
{
hide();
setFlat(true);
diff --git a/src/newui/button.h b/src/newui/button.h
index 3dbc63ca..ecb4d2ab 100644
--- a/src/newui/button.h
+++ b/src/newui/button.h
@@ -41,7 +41,7 @@ class Button : public TQPushButton {
Q_OBJECT
TQ_OBJECT
public:
- Button(ButtonBar *tqparent, const TQString text, const TQIconSet &icon = TQIconSet(),
+ Button(ButtonBar *parent, const TQString text, const TQIconSet &icon = TQIconSet(),
const TQString &description = TQString());
/**Sets the description used as a tooltip.*/
diff --git a/src/newui/buttonbar.cpp b/src/newui/buttonbar.cpp
index 55f55fb4..efc504a7 100644
--- a/src/newui/buttonbar.cpp
+++ b/src/newui/buttonbar.cpp
@@ -32,8 +32,8 @@ namespace Ideal {
//ButtonLayout class
-ButtonLayout::ButtonLayout(ButtonBar *tqparent, Direction d, int margin, int spacing, const char *name)
- :TQBoxLayout(tqparent, d, margin, spacing, name), m_buttonBar(tqparent)
+ButtonLayout::ButtonLayout(ButtonBar *parent, Direction d, int margin, int spacing, const char *name)
+ :TQBoxLayout(parent, d, margin, spacing, name), m_buttonBar(parent)
{
}
@@ -62,8 +62,8 @@ TQSize ButtonLayout::tqminimumSize() const
//ButtonBar class
-ButtonBar::ButtonBar(Place place, ButtonMode mode, TQWidget *tqparent, const char *name)
- :TQWidget(tqparent, name), m_place(place), l(0), m_shrinked(false), m_autoResize(true)
+ButtonBar::ButtonBar(Place place, ButtonMode mode, TQWidget *parent, const char *name)
+ :TQWidget(parent, name), m_place(place), l(0), m_shrinked(false), m_autoResize(true)
{
switch (m_place)
{
diff --git a/src/newui/buttonbar.h b/src/newui/buttonbar.h
index f8f13868..156b2c6d 100644
--- a/src/newui/buttonbar.h
+++ b/src/newui/buttonbar.h
@@ -37,7 +37,7 @@ class ButtonBar;
Overrides tqminimumSize method to allow shrinking button bar buttons.*/
class ButtonLayout: public TQBoxLayout{
public:
- ButtonLayout(ButtonBar *tqparent, Direction d, int margin = 0, int spacing = -1, const char * name = 0);
+ ButtonLayout(ButtonBar *parent, Direction d, int margin = 0, int spacing = -1, const char * name = 0);
virtual TQSize tqminimumSize() const;
@@ -56,7 +56,7 @@ class ButtonBar : public TQWidget {
TQ_OBJECT
public:
ButtonBar(Place place, ButtonMode mode = IconsAndText,
- TQWidget *tqparent = 0, const char *name = 0);
+ TQWidget *parent = 0, const char *name = 0);
virtual ~ButtonBar();
/**Adds a button to the bar.*/
diff --git a/src/newui/ddockwindow.cpp b/src/newui/ddockwindow.cpp
index 8394b00f..bf7cc627 100644
--- a/src/newui/ddockwindow.cpp
+++ b/src/newui/ddockwindow.cpp
@@ -39,9 +39,9 @@
#include "button.h"
#include "dmainwindow.h"
-DDockWindow::DDockWindow(DMainWindow *tqparent, Position position)
- :TQDockWindow(TQDockWindow::InDock, tqparent), m_position(position), m_visible(false),
- m_mainWindow(tqparent), m_doNotCloseActiveWidget(false), m_toggledButton(0), m_lastContextMenuButton(0)
+DDockWindow::DDockWindow(DMainWindow *parent, Position position)
+ :TQDockWindow(TQDockWindow::InDock, parent), m_position(position), m_visible(false),
+ m_mainWindow(parent), m_doNotCloseActiveWidget(false), m_toggledButton(0), m_lastContextMenuButton(0)
{
setMovingEnabled(false);
setResizeEnabled(true);
@@ -347,7 +347,7 @@ bool DDockWindow::isActive()
else
{
do {
- w = (TQWidget*)w->tqparent();
+ w = (TQWidget*)w->parent();
if (w && (w == toolWidget)) return true;
} while (w);
}
diff --git a/src/newui/ddockwindow.h b/src/newui/ddockwindow.h
index e9850d2f..d98aa375 100644
--- a/src/newui/ddockwindow.h
+++ b/src/newui/ddockwindow.h
@@ -44,7 +44,7 @@ class DDockWindow : public TQDockWindow {
public:
enum Position { Bottom, Left, Right };
- DDockWindow(DMainWindow *tqparent, Position position);
+ DDockWindow(DMainWindow *parent, Position position);
virtual ~DDockWindow();
virtual void setVisible(bool v);
diff --git a/src/newui/dmainwindow.cpp b/src/newui/dmainwindow.cpp
index 68e8883d..32d47244 100644
--- a/src/newui/dmainwindow.cpp
+++ b/src/newui/dmainwindow.cpp
@@ -29,8 +29,8 @@
#include "dtabwidget.h"
#include "docksplitter.h"
-DMainWindow::DMainWindow(TQWidget *tqparent, const char *name)
- :KParts::MainWindow(tqparent, name), m_firstRemoved(false), m_currentWidget(0)
+DMainWindow::DMainWindow(TQWidget *parent, const char *name)
+ :KParts::MainWindow(parent, name), m_firstRemoved(false), m_currentWidget(0)
{
loadSettings();
createToolWindows();
diff --git a/src/newui/dmainwindow.h b/src/newui/dmainwindow.h
index f20cfec9..28e0340f 100644
--- a/src/newui/dmainwindow.h
+++ b/src/newui/dmainwindow.h
@@ -35,7 +35,7 @@ class DMainWindow: public KParts::MainWindow {
Q_OBJECT
TQ_OBJECT
public:
- DMainWindow(TQWidget *tqparent = 0, const char *name = 0);
+ DMainWindow(TQWidget *parent = 0, const char *name = 0);
virtual ~DMainWindow();
/**@return The tool window in given @p position.*/
diff --git a/src/newui/docksplitter.cpp b/src/newui/docksplitter.cpp
index c22f2723..647c5f43 100644
--- a/src/newui/docksplitter.cpp
+++ b/src/newui/docksplitter.cpp
@@ -23,8 +23,8 @@
namespace Ideal {
-DockSplitter::DockSplitter(Qt::Orientation orientation, TQWidget *tqparent, const char *name)
- :TQSplitter(tqparent, name), m_orientation(orientation)
+DockSplitter::DockSplitter(Qt::Orientation orientation, TQWidget *parent, const char *name)
+ :TQSplitter(parent, name), m_orientation(orientation)
{
switch (m_orientation)
{
diff --git a/src/newui/docksplitter.h b/src/newui/docksplitter.h
index c5450b1a..fc66387c 100644
--- a/src/newui/docksplitter.h
+++ b/src/newui/docksplitter.h
@@ -34,7 +34,7 @@ class DockSplitter: public TQSplitter {
Q_OBJECT
TQ_OBJECT
public:
- DockSplitter(Qt::Orientation orientation, TQWidget *tqparent = 0, const char *name = 0);
+ DockSplitter(Qt::Orientation orientation, TQWidget *parent = 0, const char *name = 0);
~DockSplitter();
void addDock(uint row, uint col, TQWidget *dock);
diff --git a/src/newui/dtabwidget.cpp b/src/newui/dtabwidget.cpp
index 7ee27915..54fbee41 100644
--- a/src/newui/dtabwidget.cpp
+++ b/src/newui/dtabwidget.cpp
@@ -26,8 +26,8 @@
#include <kiconloader.h>
#include <kapplication.h>
-DTabWidget::DTabWidget(TQWidget *tqparent, const char *name)
- :KTabWidget(tqparent, name), m_closeButton(0)
+DTabWidget::DTabWidget(TQWidget *parent, const char *name)
+ :KTabWidget(parent, name), m_closeButton(0)
{
setFocusPolicy(TQ_NoFocus);
setMargin(0);
diff --git a/src/newui/dtabwidget.h b/src/newui/dtabwidget.h
index fd480c73..4c52a517 100644
--- a/src/newui/dtabwidget.h
+++ b/src/newui/dtabwidget.h
@@ -28,7 +28,7 @@ class DTabWidget: public KTabWidget {
Q_OBJECT
TQ_OBJECT
public:
- DTabWidget(TQWidget *tqparent=0, const char *name=0);
+ DTabWidget(TQWidget *parent=0, const char *name=0);
/**@return The close button at the top right corner.
May be 0 if the configuration do not allow close buttons or the tabbar.*/
diff --git a/src/partcontroller.cpp b/src/partcontroller.cpp
index 4c9c6c6f..ccfafd10 100644
--- a/src/partcontroller.cpp
+++ b/src/partcontroller.cpp
@@ -89,8 +89,8 @@ struct ModificationData
};
-PartController::PartController(TQWidget *tqparent)
- : KDevPartController(tqparent), _editorFactory(0L), m_currentActivePart(0), m_removingActivePart(false)
+PartController::PartController(TQWidget *parent)
+ : KDevPartController(parent), _editorFactory(0L), m_currentActivePart(0), m_removingActivePart(false)
{
connect(this, TQT_SIGNAL(partRemoved(KParts::Part*)), this, TQT_SLOT(slotPartRemoved(KParts::Part* )) );
connect(this, TQT_SIGNAL(partAdded(KParts::Part*)), this, TQT_SLOT(slotPartAdded(KParts::Part* )) );
@@ -109,10 +109,10 @@ PartController::~PartController()
}
-void PartController::createInstance(TQWidget *tqparent)
+void PartController::createInstance(TQWidget *parent)
{
if (!s_instance)
- s_instance = new PartController(tqparent);
+ s_instance = new PartController(parent);
}
diff --git a/src/partcontroller.h b/src/partcontroller.h
index dbb6a632..9e563914 100644
--- a/src/partcontroller.h
+++ b/src/partcontroller.h
@@ -48,7 +48,7 @@ class PartController : public KDevPartController
public:
PartController(TQWidget *toplevel);
- static void createInstance(TQWidget *tqparent);
+ static void createInstance(TQWidget *parent);
static PartController *getInstance();
///// KDevPartController interface
diff --git a/src/pluginselectdialog.cpp b/src/pluginselectdialog.cpp
index e6973d79..0414fd8d 100644
--- a/src/pluginselectdialog.cpp
+++ b/src/pluginselectdialog.cpp
@@ -27,9 +27,9 @@ class PluginItem : public TQCheckListItem
{
public:
// name - "Name", label - "GenericName", info - "Comment"
- PluginItem( TQListView * tqparent, TQString const & name, TQString const & label,
+ PluginItem( TQListView * parent, TQString const & name, TQString const & label,
TQString const & info, TQString const url = TQString() )
- : TQCheckListItem( tqparent, label, TQCheckListItem::CheckBox),
+ : TQCheckListItem( parent, label, TQCheckListItem::CheckBox),
_name( name ), _info( info ), _url( url )
{}
@@ -44,8 +44,8 @@ private:
};
-PluginSelectDialog::PluginSelectDialog(TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : PluginSelectDialogBase( tqparent,name, modal,fl )
+PluginSelectDialog::PluginSelectDialog(TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : PluginSelectDialogBase( parent,name, modal,fl )
{
plugin_list->setResizeMode( TQListView::LastColumn );
plugin_list->addColumn("");
diff --git a/src/pluginselectdialog.h b/src/pluginselectdialog.h
index 47316ef5..3adfdac4 100644
--- a/src/pluginselectdialog.h
+++ b/src/pluginselectdialog.h
@@ -23,7 +23,7 @@ class PluginSelectDialog : public PluginSelectDialogBase
TQ_OBJECT
public:
- PluginSelectDialog( TQWidget* tqparent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+ PluginSelectDialog( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
~PluginSelectDialog();
TQStringList unselectedPluginNames();
diff --git a/src/profileengine/editor/profileeditor.cpp b/src/profileengine/editor/profileeditor.cpp
index ca6b6633..a80be429 100644
--- a/src/profileengine/editor/profileeditor.cpp
+++ b/src/profileengine/editor/profileeditor.cpp
@@ -40,15 +40,15 @@
class ProfileItem: public KListViewItem {
public:
- ProfileItem(KListView *tqparent, Profile *profile)
- :KListViewItem(tqparent), m_profile(profile)
+ ProfileItem(KListView *parent, Profile *profile)
+ :KListViewItem(parent), m_profile(profile)
{
setText(0, profile->genericName());
setText(1, profile->description());
}
- ProfileItem(KListViewItem *tqparent, Profile *profile)
- : KListViewItem(tqparent), m_profile(profile)
+ ProfileItem(KListViewItem *parent, Profile *profile)
+ : KListViewItem(parent), m_profile(profile)
{
setText(0, profile->genericName());
setText(1, profile->description());
@@ -62,8 +62,8 @@ private:
class EDListItem: public KListViewItem{
public:
- EDListItem(KListView *tqparent, const TQString &text, bool derived)
- : KListViewItem(tqparent, text), m_derived(derived)
+ EDListItem(KListView *parent, const TQString &text, bool derived)
+ : KListViewItem(parent, text), m_derived(derived)
{
}
@@ -84,16 +84,16 @@ private:
class ProfileListBuilding {
public:
- ProfileItem * operator() (ProfileItem *tqparent, Profile *profile)
+ ProfileItem * operator() (ProfileItem *parent, Profile *profile)
{
- tqparent->setOpen(true);
- return new ProfileItem(tqparent, profile);
+ parent->setOpen(true);
+ return new ProfileItem(parent, profile);
}
};
-ProfileEditor::ProfileEditor(TQWidget *tqparent, const char *name)
- :ProfileEditorBase(tqparent, name)
+ProfileEditor::ProfileEditor(TQWidget *parent, const char *name)
+ :ProfileEditorBase(parent, name)
{
refresh();
}
@@ -258,7 +258,7 @@ void ProfileEditor::removeProfile()
if (profile->remove())
{
TQListViewItem *item = profilesList->currentItem();
- profilesList->setCurrentItem(item->tqparent());
+ profilesList->setCurrentItem(item->parent());
profile->detachFromParent();
delete profile;
delete item;
diff --git a/src/profileengine/editor/profileeditor.h b/src/profileengine/editor/profileeditor.h
index aae785b1..b3c97215 100644
--- a/src/profileengine/editor/profileeditor.h
+++ b/src/profileengine/editor/profileeditor.h
@@ -31,7 +31,7 @@ class ProfileEditor : public ProfileEditorBase {
Q_OBJECT
TQ_OBJECT
public:
- ProfileEditor(TQWidget *tqparent = 0, const char *name = 0);
+ ProfileEditor(TQWidget *parent = 0, const char *name = 0);
public slots:
virtual void removeProperty();
diff --git a/src/profileengine/lib/profile.cpp b/src/profileengine/lib/profile.cpp
index a5ad5803..02fe1216 100644
--- a/src/profileengine/lib/profile.cpp
+++ b/src/profileengine/lib/profile.cpp
@@ -26,8 +26,8 @@
#include <kconfig.h>
#include <kio/netaccess.h>
-Profile::Profile(Profile *tqparent, const TQString &name)
- :m_parent(tqparent), m_name(name)
+Profile::Profile(Profile *parent, const TQString &name)
+ :m_parent(parent), m_name(name)
{
if (m_parent)
m_parent->addChildProfile(this);
@@ -49,8 +49,8 @@ Profile::Profile(Profile *tqparent, const TQString &name)
m_explicitDisable = config.readListEntry("List");
}
-Profile::Profile(Profile *tqparent, const TQString &name, const TQString &genericName, const TQString &description)
- :m_parent(tqparent), m_name(name), m_genericName(genericName), m_description(description)
+Profile::Profile(Profile *parent, const TQString &name, const TQString &genericName, const TQString &description)
+ :m_parent(parent), m_name(name), m_genericName(genericName), m_description(description)
{
if (m_parent)
m_parent->addChildProfile(this);
diff --git a/src/profileengine/lib/profile.h b/src/profileengine/lib/profile.h
index 30e00517..c6829245 100644
--- a/src/profileengine/lib/profile.h
+++ b/src/profileengine/lib/profile.h
@@ -45,12 +45,12 @@ public:
ExplicitDisable /**<A list of explicitly disabled plugins (names).*/
};
- Profile(Profile *tqparent, const TQString &name);
- Profile(Profile *tqparent, const TQString &name, const TQString &genericName, const TQString &description);
+ Profile(Profile *parent, const TQString &name);
+ Profile(Profile *parent, const TQString &name, const TQString &genericName, const TQString &description);
~Profile();
TQValueList<Profile*> tqchildren() const { return m_tqchildren; }
- Profile *tqparent() const { return m_parent; }
+ Profile *parent() const { return m_parent; }
void save();
bool remove();
diff --git a/src/profileengine/lib/profileengine.h b/src/profileengine/lib/profileengine.h
index 9184df62..90908afe 100644
--- a/src/profileengine/lib/profileengine.h
+++ b/src/profileengine/lib/profileengine.h
@@ -189,7 +189,7 @@ public:
but the operation in this case returns a result of type defined by
"Result" template parameter.
- When iterating the tree, the result of operation applied to the tqparent profile
+ When iterating the tree, the result of operation applied to the parent profile
is passed as @p result parameter to the recursive call for child profiles.
For example, this function can be used to build another hierarcy of profiles
@@ -199,24 +199,24 @@ public:
@code
class ProfileListBuilding {
public:
- ProfileItem * operator() (ProfileItem *tqparent, Profile *profile)
+ ProfileItem * operator() (ProfileItem *parent, Profile *profile)
{
- tqparent->setOpen(true);
- return new ProfileItem(tqparent, profile);
+ parent->setOpen(true);
+ return new ProfileItem(parent, profile);
}
};
class ProfileItem: public KListViewItem {
public:
- ProfileItem(KListView *tqparent, Profile *profile)
- :KListViewItem(tqparent), m_profile(profile)
+ ProfileItem(KListView *parent, Profile *profile)
+ :KListViewItem(parent), m_profile(profile)
{
setText(0, profile->genericName());
setText(1, profile->description());
}
- ProfileItem(KListViewItem *tqparent, Profile *profile)
- : KListViewItem(tqparent), m_profile(profile)
+ ProfileItem(KListViewItem *parent, Profile *profile)
+ : KListViewItem(parent), m_profile(profile)
{
setText(0, profile->genericName());
setText(1, profile->description());
diff --git a/src/projectsession.cpp b/src/projectsession.cpp
index c471366f..2676f56b 100644
--- a/src/projectsession.cpp
+++ b/src/projectsession.cpp
@@ -244,7 +244,7 @@ bool ProjectSession::saveToFile( const TQString & sessionFileName, const TQValue
//// mainframeEl=domdoc.createElement("Mainframe");
//// session.appendChild( mainframeEl);
//// }
-//// bool bMaxMode = ((QextMdiMainFrm*)m_pDocViewMan->tqparent())->isInMaximizedChildFrmMode();
+//// bool bMaxMode = ((QextMdiMainFrm*)m_pDocViewMan->parent())->isInMaximizedChildFrmMode();
//// mainframeEl.setAttribute("MaximizeMode", bMaxMode);
diff --git a/src/settingswidget.ui b/src/settingswidget.ui
index 305f7e4e..92d4554e 100644
--- a/src/settingswidget.ui
+++ b/src/settingswidget.ui
@@ -163,7 +163,7 @@
<string>Set the directory where you want your projects in.</string>
</property>
<property name="whatsThis" stdset="0">
- <string>By default, KDevelop uses a common tqparent directory for all new projects. Enter the absolute path of this common directory in the box or select it from your directory structure. KDevelop will place the any new project here as a subdirectory.</string>
+ <string>By default, KDevelop uses a common parent directory for all new projects. Enter the absolute path of this common directory in the box or select it from your directory structure. KDevelop will place the any new project here as a subdirectory.</string>
</property>
</widget>
</hbox>
diff --git a/src/simplemainwindow.h b/src/simplemainwindow.h
index 19ef20b2..193c70eb 100644
--- a/src/simplemainwindow.h
+++ b/src/simplemainwindow.h
@@ -38,7 +38,7 @@ class SimpleMainWindow: public DMainWindow, public KDevMainWindow {
Q_OBJECT
TQ_OBJECT
public:
- SimpleMainWindow(TQWidget* tqparent = 0, const char *name = 0);
+ SimpleMainWindow(TQWidget* parent = 0, const char *name = 0);
virtual ~SimpleMainWindow();
virtual void embedPartView(TQWidget *view, const TQString &title, const TQString& toolTip = TQString());
diff --git a/src/statusbar.cpp b/src/statusbar.cpp
index 581c2fd2..267e3e2c 100644
--- a/src/statusbar.cpp
+++ b/src/statusbar.cpp
@@ -27,8 +27,8 @@
#include "statusbar.h"
#include "partcontroller.h"
-KDevStatusBar::KDevStatusBar(TQWidget *tqparent, const char *name)
- : KStatusBar(tqparent, name), _cursorIface(0), _activePart(0)
+KDevStatusBar::KDevStatusBar(TQWidget *parent, const char *name)
+ : KStatusBar(parent, name), _cursorIface(0), _activePart(0)
{
TQWidget * w = new TQWidget( this );
addWidget( w, 1, true );
diff --git a/src/statusbar.h b/src/statusbar.h
index 1c325fcf..e63a8ad0 100644
--- a/src/statusbar.h
+++ b/src/statusbar.h
@@ -30,7 +30,7 @@ class KDevStatusBar : public KStatusBar
TQ_OBJECT
public:
- KDevStatusBar( TQWidget *tqparent=0, const char *name=0 );
+ KDevStatusBar( TQWidget *parent=0, const char *name=0 );
~KDevStatusBar();
void addWidget ( TQWidget *widget, int stretch = 0, bool permanent = FALSE );
diff --git a/src/multibuffer.cpp b/src/multibuffer.cpp
index 404a0bae..70975de5 100644
--- a/src/multibuffer.cpp
+++ b/src/multibuffer.cpp
@@ -45,8 +45,8 @@
#include <ktexteditor/document.h>
#include <ktexteditor/viewcursorinterface.h>
-MultiBuffer::MultiBuffer( TQWidget *tqparent )
- : TQSplitter( tqparent, "MultiBuffer" ),
+MultiBuffer::MultiBuffer( TQWidget *parent )
+ : TQSplitter( parent, "MultiBuffer" ),
m_editorFactory( 0 ),
m_delayActivate( false ),
m_activated( false ),
@@ -219,7 +219,7 @@ void MultiBuffer::show()
KTextEditor::View *view = document->createView( this );
document->setWidget( view );
// We're managing the view deletion by being its tqparent,
// don't let the part self-destruct
disconnect( view, TQT_SIGNAL( destroyed() ),
document, TQT_SLOT( slotWidgetDestroyed() ) );
@@ -219,7 +219,7 @@ void MultiBuffer::show()
KTextEditor::View *view = document->createView( this );
document->setWidget( view );
- // We're managing the view deletion by being its tqparent,
+ // We're managing the view deletion by being its parent,
// don't let the part self-destruct
disconnect( view, TQT_SIGNAL( destroyed() ),
diff --git a/src/simplemainwindow.cpp b/src/simplemainwindow.cpp
index 1f2c4dd5..e98ce01c 100644
--- a/src/simplemainwindow.cpp
+++ b/src/simplemainwindow.cpp
@@ -57,8 +57,8 @@
#include "editorproxy.h"
#include "multibuffer.h"
-SimpleMainWindow::SimpleMainWindow(TQWidget* tqparent, const char *name)
- :DMainWindow(tqparent, name)
+SimpleMainWindow::SimpleMainWindow(TQWidget* parent, const char *name)
+ :DMainWindow(parent, name)
{
resize(800, 600); // starts kdevelop at 800x600 the first time
m_mainWindowShare = new MainWindowShare(TQT_TQOBJECT(this));
@@ -322,15 +322,15 @@ void SimpleMainWindow::raiseView(TQWidget *view)
{
//adymo: a workaround to make editor wrappers work:
//editor view is passed to this function but the ui library knows only
//of its tqparent which is an editor wrapper, simply replacing the view
//by its wrapper helps here
- if (view->tqparent())
- kdDebug() << view->tqparent()->className() << endl;
- if (view->tqparent() && (view->tqparent()->isA("EditorWrapper") || view->tqparent()->isA("MultiBuffer")))
+ if (view->parent())
+ kdDebug() << view->parent()->className() << endl;
+ if (view->parent() && (view->parent()->isA("EditorWrapper") || view->parent()->isA("MultiBuffer")))
{
-// kdDebug() << "tqparent is editor wrapper: " <<
-// static_cast<EditorWrapper*>(view->tqparent()) << endl;
- view = (TQWidget*)view->tqparent();
+// kdDebug() << "parent is editor wrapper: " <<
+// static_cast<EditorWrapper*>(view->parent()) << endl;
+ view = (TQWidget*)view->parent();
}
if (hasDockWidget(view))
@@ -577,9 +577,9 @@ void SimpleMainWindow::documentChangedState(const KURL &url, DocumentState state
void SimpleMainWindow::closeTab()
{
// actionCollection()->action("file_close")->activate();
- if (TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->isA(TQTOOLBUTTON_OBJECT_NAME_STRING) && TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->tqparent()->isA("DTabWidget"))
+ if (TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->isA(TQTOOLBUTTON_OBJECT_NAME_STRING) && TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->parent()->isA("DTabWidget"))
{
- DTabWidget *tab = (DTabWidget*)TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->tqparent();
+ DTabWidget *tab = (DTabWidget*)TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->parent();
if (tab && tab->currentPage())
closeTab(tab->currentPage());
}
@@ -847,13 +847,13 @@ TQWidget *SimpleMainWindow::widgetForURL(KURL url)
TQWidget *SimpleMainWindow::widgetInTab(TQWidget *w)
{
TQWidget *inTab = 0;
- if (w && w->tqparent() && w->tqparent()->isA("EditorProxy"))
- inTab = (TQWidget*)w->tqparent();
- else if (w && w->tqparent() && w->tqparent()->isA("MultiBuffer")
- && w->tqparent()->tqparent() && w->tqparent()->tqparent()->isA("EditorProxy"))
- inTab = (TQWidget*)w->tqparent()->tqparent();
- else if (w && w->tqparent() && w->tqparent()->isA("MultiBuffer"))
- inTab = (TQWidget*)w->tqparent();
+ if (w && w->parent() && w->parent()->isA("EditorProxy"))
+ inTab = (TQWidget*)w->parent();
+ else if (w && w->parent() && w->parent()->isA("MultiBuffer")
+ && w->parent()->parent() && w->parent()->parent()->isA("EditorProxy"))
+ inTab = (TQWidget*)w->parent()->parent();
+ else if (w && w->parent() && w->parent()->isA("MultiBuffer"))
+ inTab = (TQWidget*)w->parent();
else
inTab = w;
return inTab;
@@ -322,15 +322,15 @@ void SimpleMainWindow::raiseView(TQWidget *view)
//adymo: a workaround to make editor wrappers work:
//editor view is passed to this function but the ui library knows only
- //of its tqparent which is an editor wrapper, simply replacing the view
+ //of its parent which is an editor wrapper, simply replacing the view
//by its wrapper helps here